@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: Apache-2.0
+// 
 // Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
@@ -42,10 +44,31 @@ struct arma_config
   #endif
   
   
-  #if defined(ARMA_USE_ATLAS)
-    static constexpr bool atlas = true;
+  #if defined(ARMA_OPTIMISE_BAND)
+    static constexpr bool optimise_band = true;
   #else
-    static constexpr bool atlas = false;
+    static constexpr bool optimise_band = false;
+  #endif
+  
+  
+  #if defined(ARMA_OPTIMISE_SYM)
+    static constexpr bool optimise_sym = true;
+  #else
+    static constexpr bool optimise_sym = false;
+  #endif
+  
+  
+  #if defined(ARMA_OPTIMISE_INVEXPR)
+    static constexpr bool optimise_invexpr = true;
+  #else
+    static constexpr bool optimise_invexpr = false;
+  #endif
+  
+  
+  #if defined(ARMA_CHECK_NONFINITE)
+    static constexpr bool check_nonfinite = true;
+  #else
+    static constexpr bool check_nonfinite = false;
   #endif
   
   
@@ -63,6 +86,13 @@ struct arma_config
   #endif
   
   
+  #if defined(ARMA_USE_ATLAS)
+    static constexpr bool atlas = true;
+  #else
+    static constexpr bool atlas = false;
+  #endif
+  
+  
   #if defined(ARMA_USE_NEWARP)
     static constexpr bool newarp = true;
   #else
@@ -144,6 +174,13 @@ struct arma_config
   #endif
   
   
+  #if defined(ARMA_HAVE_CXX20)
+    static constexpr bool cxx20 = true;
+  #else
+    static constexpr bool cxx20 = false;
+  #endif
+  
+  
   #if (!defined(ARMA_DONT_USE_STD_MUTEX))
     static constexpr bool std_mutex = true;
   #else
@@ -179,6 +216,27 @@ struct arma_config
   #endif
   
   
+  #if defined(ARMA_DONT_ZERO_INIT)
+    static constexpr bool zero_init = false;
+  #else
+    static constexpr bool zero_init = true;
+  #endif
+  
+  
+  #if defined(ARMA_FAST_MATH)
+    static constexpr bool fast_math = true;
+  #else
+    static constexpr bool fast_math = false;
+  #endif
+  
+  
+  #if defined(ARMA_FAST_MATH) && !defined(ARMA_DONT_PRINT_FAST_MATH_WARNING)
+    static constexpr bool fast_math_warn = true;
+  #else
+    static constexpr bool fast_math_warn = false;
+  #endif
+  
+  
   static constexpr uword warn_level = (sword(ARMA_WARN_LEVEL) > 0) ? uword(ARMA_WARN_LEVEL) : 0;
   };
 
